@@ -1,15 +1,19 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
+from __future__ import division
+
 import binascii
+import functools
+import math
 import os
 import random
-import uuid
 import sys
+import uuid
 
 class WichmannHill(random.Random):
     """
@@ -108,7 +112,7 @@ class WichmannHill(random.Random):
         period.
         """
 
-        if not n >= 0:
+        if n < 0:
             raise ValueError("n must be >= 0")
         x, y, z = self._seed
         x = int(x * pow(171, n, 30269)) % 30269
@@ -162,11 +166,82 @@ class WichmannHill(random.Random):
         z = (z + a) % 256 or 1
         self.__whseed(x, y, z)
 
+def patchHeaders(headers):
+    if headers is not None and not hasattr(headers, "headers"):
+        headers.headers = ["%s: %s\r\n" % (header, headers[header]) for header in headers]
+
+def cmp(a, b):
+    """
+    >>> cmp("a", "b")
+    -1
+    >>> cmp(2, 1)
+    1
+    """
+
+    if a < b:
+        return -1
+    elif a > b:
+        return 1
+    else:
+        return 0
+
 # Reference: https://github.com/urllib3/urllib3/blob/master/src/urllib3/filepost.py
 def choose_boundary():
     return uuid.uuid4().hex
 
+# Reference: http://python3porting.com/differences.html
+def round(x, d=0):
+    """
+    >>> round(2.0)
+    2.0
+    >>> round(2.5)
+    3.0
+    """
+
+    p = 10 ** d
+    if x > 0:
+        return float(math.floor((x * p) + 0.5)) / p
+    else:
+        return float(math.ceil((x * p) - 0.5)) / p
+
+def cmp_to_key(mycmp):
+    """Convert a cmp= function into a key= function"""
+    class K(object):
+        __slots__ = ['obj']
+
+        def __init__(self, obj, *args):
+            self.obj = obj
+
+        def __lt__(self, other):
+            return mycmp(self.obj, other.obj) < 0
+
+        def __gt__(self, other):
+            return mycmp(self.obj, other.obj) > 0
+
+        def __eq__(self, other):
+            return mycmp(self.obj, other.obj) == 0
+
+        def __le__(self, other):
+            return mycmp(self.obj, other.obj) <= 0
+
+        def __ge__(self, other):
+            return mycmp(self.obj, other.obj) >= 0
+
+        def __ne__(self, other):
+            return mycmp(self.obj, other.obj) != 0
+
+        def __hash__(self):
+            raise TypeError('hash not implemented')
+
+    return K
+
+# Note: patch for Python 2.6
+if not hasattr(functools, "cmp_to_key"):
+    functools.cmp_to_key = cmp_to_key
+
 if sys.version_info >= (3, 0):
     xrange = range
+    buffer = memoryview
 else:
     xrange = xrange
+    buffer = buffer
