@@ -1,24 +1,29 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
-import os
 import zipfile
 
 from lib.core.common import getSafeExString
+from lib.core.common import isZipFile
 from lib.core.exception import SqlmapDataException
 from lib.core.exception import SqlmapInstallationException
+from thirdparty import six
 
-class Wordlist(object):
+class Wordlist(six.Iterator):
     """
     Iterator for looping over a large dictionaries
+
+    >>> from lib.core.option import paths
+    >>> isinstance(next(Wordlist(paths.SMALL_DICT)), six.string_types)
+    True
     """
 
     def __init__(self, filenames, proc_id=None, proc_count=None, custom=None):
-        self.filenames = filenames
+        self.filenames = [filenames] if isinstance(filenames, six.string_types) else filenames
         self.fp = None
         self.index = 0
         self.counter = -1
@@ -40,7 +45,7 @@ class Wordlist(object):
             self.iter = iter(self.custom)
         else:
             self.current = self.filenames[self.index]
-            if os.path.splitext(self.current)[1].lower() == ".zip":
+            if isZipFile(self.current):
                 try:
                     _ = zipfile.ZipFile(self.current, 'r')
                 except zipfile.error as ex:
@@ -63,7 +68,7 @@ class Wordlist(object):
             self.fp.close()
             self.fp = None
 
-    def next(self):
+    def __next__(self):
         retVal = None
         while True:
             self.counter += 1
