@@ -18,7 +18,7 @@ class Enumeration(GenericEnumeration):
         warnMsg = "on SQLite it is not possible to get name of the current database"
         logger.warn(warnMsg)
 
-    def isDba(self, *args, **kwargs):
+    def isDba(self, user=None):
         warnMsg = "on SQLite the current user has all privileges"
         logger.warn(warnMsg)
 
